@@ -4,6 +4,7 @@ import os
 import platform
 import subprocess
 import sys
+import time
 from pathlib import Path
 
 import tomli
@@ -40,19 +41,23 @@ def build_and_install(build_dir, source_dir, config):
 
 
 def write_version_file():
-    with dir_context(script_dir):
-        try:
-            # Create header with version info
-            with open("pyproject.toml", "rb") as f:
-                project = tomli.load(f)
-                version = project["tool"]["poetry"]["version"]
-        except OSError:
-            version = "0.0.0.dev"
+    pyproject_toml = script_dir / "pyproject.toml"
+    if not pyproject_toml.exists():
+        # For some reason, during install, poetry renames pyproject.toml to pyproject.tmp...
+        pyproject_toml = script_dir / "pyproject.tmp"
 
-    with open("src/geofun/version.h", "w") as f:
+    # Create header with version info
+    with open(pyproject_toml, "rb") as f:
+        project = tomli.load(f)
+        version = project["tool"]["poetry"]["version"]
+
+    version_h = script_dir / "src" / "geofun" / "version.h"
+    with open(version_h, "w") as f:
         f.write(f'#define VERSION "{version}"')
 
 
+write_version_file()
+
 # Build contrib packages
 install_prefix = Path("../../install")
 
@@ -68,8 +73,6 @@ cmake = python_dir / "cmake"
 build_and_install(geographic_build, geographic_source, "-DBUILD_SHARED_LIBS=OFF")
 build_and_install(fmt_build, fmt_source, "-DFMT_TEST=OFF -DCMAKE_CXX_FLAGS=-fPIC")
 
-write_version_file()
-
 
 def build(setup_kwargs):
     ext_modules = [
